@@ -217,7 +217,17 @@ class HTTPException(Exception):
 class myURLOpener(urllib.FancyURLopener):
     # read an URL, with automatic HTTP authentication
 
+    follow_redirection = True ## by default follow_redirection
 
+    def http_error_302(self, url, fp, errcode, errmsg, headers, data=None):
+        """Error 302 -- relocated (temporarily)."""
+        if self.follow_redirection is True:
+            return urllib.FancyURLopener.http_error_302(self, url,
+                                                        fp, errcode,
+                                                        errmsg, headers, data)
+        else:
+            return urllib.addinfourl(fp, headers, "http:" + url)
+        
 
     def http_error_default(self, url, fp, errcode,errmsg, headers):
         errcode = str(errcode)
@@ -1309,6 +1319,12 @@ def main():
     logger.info('BEGIN')
     Server.ping_command = config.get('DEFAULT','ping_command').split(' ')
     ZeoClient.perf_file = getPerfFile(config.get('DEFAULT','perfdir'))
+    if config.has_option('DEFAULT','follow_redirection'):
+        ## in some case we dont want follow redirection
+        if  config.get('DEFAULT','follow_redirection') in ('no','False',
+                                                           'false', '0'):
+             myURLOpener.follow_redirection = False
+
     cluster = Cluster(config)
     
     lock_path = os.path.join(os.getcwd(),config.get('DEFAULT',
